*************************************************************************************
**  Replication Code (Stata Version 14.1)
** 
**	Created: Sept 22, 2016
** 	Christine Fair, Patrick M Kuhn, Neil Malhotra, and Jake Shapiro
**	Updated: 
** 
**	File for Analysis: FKMS_PA_Data.dta (PA-Constituencey Dataset); FKMS_Ind_Data.dta (Individual-level Dataset)
*************************************************************************************
clear 
estimates clear
graph drop _all
set more off

cd "~/Desktop/QJPS/15075/Iteration 1/Replication Material"	//Set working directory to replication folder
		
use "FKMS_PA_Data.dta", clear

capture log close
log using "SummaryStatistics.txt", text replace
log off

*************************************************************************************
** Install Programs
*************************************************************************************
ssc install estout, replace //Installing estout package to create tables from stored estimtes

*************************************************************************************
** Creation of additional variables
*************************************************************************************
//Interactions with floodrisk
gen pop1011Xfloodrisk = pop1011_UNOSAT*floodrisk

//Population density
gen popdensity11 = (pop11*1000)/area
quietly: sum popdensity11, detail
gen urban = popdensity11>r(p75)

//Interaction between urbanization and flood treatment
gen pop1011Xurban = pop1011_UNOSAT * urban
gen pop1011XurbanXrisk = pop1011Xurban * floodrisk

//Proper PA labeling
egen pa_name = concat(pid pa_num), punct(-)

//Generate sample variable
gen fullsamp = 1
gen nneighsamp = neigh_Rivers==1|nneigh_Rivers==1
gen neighsamp = neigh_Rivers==1

//Generate province samples
gen allsamp=1
gen sindh=province=="SINDH"
gen baloch_kpk=province=="BALOCHISTAN"|province=="KPK"
gen punjab=province=="PUNJAB"

//Dummy for meaningful flood risk 
gen frg1 = floodrisk>=1
gen pop1011Xfrg1 = pop1011_UNOSAT*frg1

//Squared term for flooding
gen pop1011_UNOSAT_sq = pop1011_UNOSAT^2

//Alternative turnout measures based on valid votes
gen vturnout02 = vtotal02/rvoters02
gen vturnout08 = vtotal08/rvoters08
gen vturnout13 = vtotal13/rvoters13

gen d_vt0802 = vturnout08-vturnout02
gen d_vt1308 = vturnout13-vturnout08

*************************************************************************************
** Tables Main Paper 
*************************************************************************************

keep if division!=""

//Set controls  
local maincontrols floodrisk centdist_MRiver neigh_Rivers dem_std dem_mean pop12_UNOSAT
local placebocontrols floodrisk centdist_MRiver neigh_Rivers dem_std dem_mean
local grphcontrols centdist_MRiver neigh_Rivers dem_std dem_mean pop12_UNOSAT
local votesharecontrols ppp08 pmln08 pmlq08 comp08 comp08Xppp08 comp08Xpmln08 comp08Xpmlq08 pop12_UNOSAT floodrisk centdist_MRiver neigh_Rivers dem_std dem_mean

//Table 1: Main Result Full Sample with Different Controls

forvalues j=1/3{
	local x: word `j' of " " "d_t0802" "turnout08 turnout02" 
			eststo t1_`j': reg turnout13 pop1011_UNOSAT `x' `maincontrols',  cluster(district)
		
			eststo t1_`j'_PFE: areg turnout13 pop1011_UNOSAT `x' `maincontrols', a(province) cluster(district)
			estadd local PFE "X"
		
			eststo t1_`j'_DFE: areg turnout13 pop1011_UNOSAT `x' `maincontrols', a(division) cluster(district)
			estadd local DFE "X"
	}	

//Table 2: Main Results for Three Different Subsets (full sample, near major rivers, neighboring major rivers) with Full Controls

forvalues i=1/3{
	local s: word `i' of fullsamp nneighsamp neighsamp
			eststo t2_`i': reg turnout13 pop1011_UNOSAT turnout08 turnout02 `maincontrols' if `s'==1,  cluster(district)
		
			eststo t2_`i'_PFE: areg turnout13 pop1011_UNOSAT turnout08 turnout02 `maincontrols' if `s'==1, a(province) cluster(district)
			estadd local PFE "X"
		
			eststo t2_`i'_DFE: areg turnout13 pop1011_UNOSAT turnout08 turnout02 `maincontrols' if `s'==1, a(division) cluster(district)
			estadd local DFE "X"	
}

//Table 3: Placebo Regressions for Three Different Subsets and Different Controls

forvalues i=1/3{
	local s: word `i' of fullsamp nneighsamp neighsamp
		forvalues j=1/3{
		local y: word `j' of turnout02 turnout08 d_t0802 
			eststo t3_`i'_`j': reg `y' pop1011_UNOSAT `placebocontrols' if `s'==1,  cluster(district)
		
			eststo t3_`i'_`j'_PFE: areg `y' pop1011_UNOSAT `placebocontrols' if `s'==1, a(province) cluster(district)
			estadd local PFE "X"
		
			eststo t3_`i'_`j'_DFE:	areg `y' pop1011_UNOSAT `placebocontrols' if `s'==1, a(division) cluster(district)
			estadd local DFE "X"
	}
}

//Table 4: Vote Share Regressions with Full Set of Controls
rename prov08 prov13_08
rename vsPPPP08 vsPPPP13_08 
rename vsPML_N08 vsPML_N13_08

forvalues i=1/3{
	local y: word `i' of prov13 vsPPPP13 vsPML_N13
		forvalues j=1/4{
		local s: word `j' of allsamp baloch_kpk punjab sindh
			eststo t4_`i'_`j':  reg `y' pop1011_UNOSAT `y'_08 `maincontrols' if `s'==1, cluster(district)

			eststo t4_`i'_`j'_DFE:	areg `y' pop1011_UNOSAT `y'_08 `maincontrols' if `s'==1, a(division) cluster(district)
			estadd local DFE "X"
	}
}

//Table 5: Continuous and Dichotmous Interaction with Flood Risk
//Continuous

summ floodrisk, d
local risk_25p `r(p25)'
local risk_50p `r(p50)' 
local risk_75p `r(p75)' 

forvalues j=1/3{
	local x: word `j' of " " "d_t0802" "turnout08 turnout02" 
		reg turnout13 pop1011_UNOSAT pop1011Xfloodrisk `x' `maincontrols',  cluster(district)
		lincom  pop1011_UNOSAT + `risk_25p'*pop1011Xfloodrisk
		estadd scalar coeff1 r(estimate)
		estadd scalar se1    r(se)
		lincom  pop1011_UNOSAT + `risk_50p'*pop1011Xfloodrisk
		estadd scalar coeff2 r(estimate)
		estadd scalar se2    r(se)
		lincom  pop1011_UNOSAT + `risk_75p'*pop1011Xfloodrisk
		estadd scalar coeff3 r(estimate)
		estadd scalar se3    r(se)
		eststo t5A_`j'
		
		areg turnout13 pop1011_UNOSAT pop1011Xfloodrisk `x' `maincontrols', a(province) cluster(district)
		estadd local PFE "X"
		lincom  pop1011_UNOSAT + `risk_25p'*pop1011Xfloodrisk
		estadd scalar coeff1 r(estimate)
		estadd scalar se1   r(se)
		lincom  pop1011_UNOSAT + `risk_50p'*pop1011Xfloodrisk
		estadd scalar coeff2 r(estimate)
		estadd scalar se2   r(se)
		lincom  pop1011_UNOSAT + `risk_75p'*pop1011Xfloodrisk
		estadd scalar coeff3 r(estimate)
		estadd scalar se3   r(se)
		eststo t5A_`j'_PFE
		
	    areg turnout13 pop1011_UNOSAT pop1011Xfloodrisk `x' `maincontrols', a(division) cluster(district)
		estadd local DFE "X"
		lincom  pop1011_UNOSAT + `risk_25p'*pop1011Xfloodrisk
	    estadd scalar coeff1 r(estimate)
		estadd scalar se1    r(se)
		lincom  pop1011_UNOSAT + `risk_50p'*pop1011Xfloodrisk
		estadd scalar coeff2 r(estimate)
		estadd scalar se2    r(se)
		lincom  pop1011_UNOSAT + `risk_75p'*pop1011Xfloodrisk
		estadd scalar coeff3 r(estimate)
		estadd scalar se3    r(se)
         eststo t5A_`j'_DFE	
	}		
	
//Create Maginplot of Interaction 
quietly: reg turnout13 pop1011_UNOSAT floodrisk c.pop1011_UNOSAT#c.floodrisk turnout08 turnout02 `grphcontrols',  cluster(district)
margins, dydx(pop1011_UNOSAT) at(floodrisk=(0(1)5))
marginsplot, x(floodrisk) plotopts(connect(none)) yline(0) yscale(range(-0.25 0.4)) ///
	title("No Fixed Effects") xtitle("") ytitle("Marginal Effect") scheme(s1mono) name(g1)

quietly: areg turnout13 pop1011_UNOSAT floodrisk c.pop1011_UNOSAT#c.floodrisk turnout08 turnout02 `grphcontrols', a(province) cluster(district)
margins, dydx(pop1011_UNOSAT) at(floodrisk=(0(1)5))
marginsplot, x(floodrisk) plotopts(connect(none)) yline(0) yscale(range(-0.25 0.4)) ///
	title("Province Fixed Effects") xtitle("UNEP Ex Ante Flood Risk") ytitle("Marginal Effect") scheme(s1mono) name(g2)

quietly: areg turnout13 pop1011_UNOSAT floodrisk c.pop1011_UNOSAT#c.floodrisk turnout08 turnout02 `grphcontrols', a(division) cluster(district)
margins, dydx(pop1011_UNOSAT) at(floodrisk=(0(1)5))
marginsplot, x(floodrisk) plotopts(connect(none)) yline(0) yscale(range(-0.25 0.4)) ///
	title("Division Fixed Effects") xtitle("UNEP Ex Ante Flood Risk") ytitle("Marginal Effect") scheme(s1mono) name(g3)

graph combine g1 g2 g3, hole(2) ycommon title("Controls & Levels") scheme(s1mono)
graph export "Figures/AMEbyFloodRisk.pdf", replace

	
//Dichotomous

summ pop1011_UNOSAT if area1011_UNOSAT>0, d
local impact_50p `r(p50)' 
local impact_75p `r(p75)'
local impact_90p `r(p90)'

forvalues j=1/3{
	local x: word `j' of " " "d_t0802" "turnout08 turnout02" 
		reg turnout13 pop1011_UNOSAT frg1 pop1011Xfrg1 `x' `maincontrols',  cluster(district)
		lincom `impact_50p'*pop1011_UNOSAT - (`impact_50p'*pop1011_UNOSAT + frg1 + `impact_50p'*pop1011Xfrg1)
				estadd scalar coeff1 r(estimate)
			    estadd scalar se1   r(se)
		lincom `impact_75p'*pop1011_UNOSAT - (`impact_75p'*pop1011_UNOSAT + frg1 + `impact_75p'*pop1011Xfrg1)
				estadd scalar coeff2 r(estimate)
			    estadd scalar se2   r(se)
		lincom `impact_90p'*pop1011_UNOSAT - (`impact_90p'*pop1011_UNOSAT  + frg1 + `impact_90p'*pop1011Xfrg1)	
				estadd scalar coeff3 r(estimate)
			    estadd scalar se3   r(se)
        eststo t5B_`j'
		
		areg turnout13 pop1011_UNOSAT frg1 pop1011Xfrg1 `x' `maincontrols', a(province) cluster(district)
		estadd local PFE "X"
		lincom `impact_50p'*pop1011_UNOSAT - (`impact_50p'*pop1011_UNOSAT + frg1 + `impact_50p'*pop1011Xfrg1)
				estadd scalar coeff1 r(estimate)
			    estadd scalar se1    r(se)
		lincom `impact_75p'*pop1011_UNOSAT - (`impact_75p'*pop1011_UNOSAT + frg1 + `impact_75p'*pop1011Xfrg1)
				estadd scalar coeff2 r(estimate)
			    estadd scalar se2    r(se)
		lincom `impact_90p'*pop1011_UNOSAT - (`impact_90p'*pop1011_UNOSAT  + frg1 + `impact_90p'*pop1011Xfrg1)	
				estadd scalar coeff3 r(estimate)
			    estadd scalar se3    r(se)
		eststo t5B_`j'_PFE
		
		areg turnout13 pop1011_UNOSAT frg1 pop1011Xfrg1 `x' `maincontrols', a(division) cluster(district)
		estadd local DFE "X"
		lincom `impact_50p'*pop1011_UNOSAT - (`impact_50p'*pop1011_UNOSAT + frg1 + `impact_50p'*pop1011Xfrg1)
				estadd scalar coeff1 r(estimate)
			    estadd scalar se1    r(se)
		lincom `impact_75p'*pop1011_UNOSAT - (`impact_75p'*pop1011_UNOSAT + frg1 + `impact_75p'*pop1011Xfrg1)
				estadd scalar coeff2 r(estimate)
			    estadd scalar se2    r(se)
		lincom `impact_90p'*pop1011_UNOSAT - (`impact_90p'*pop1011_UNOSAT  + frg1 + `impact_90p'*pop1011Xfrg1)	
				estadd scalar coeff3 r(estimate)
			    estadd scalar se3    r(se)
        eststo t5B_`j'_DFE
}		

log on
*************************************************************************************
** Appendix A: Summary Statistics
*************************************************************************************

//Outcomes
sum turnout02 turnout08 turnout13 d_t0802 vtotal13 vcast13 rvoters13 prov13 vsPPPP13 vsPML_N13, detail

//Flood treatment
sum pop1011_UNOSAT, detail

//Controls 
sum ppp08 pmln08 pmlq08 comp08, detail
sum floodrisk frg1 centdist_MRiver neigh_Rivers dem_std dem_mean pop12_UNOSAT, detail
sum vcast08 vtotal08 rvoters08 vcast02 vtotal02 rvoters02 totrelief migrated_NDMA, detail

log off
*************************************************************************************
** Appendix B: Additional PA-Constituency Results
*************************************************************************************

//Table B.1: Non-linear Response

local impact_50p2= (`impact_50p')^2
local impact_75p2= (`impact_75p')^2
local impact_90p2= (`impact_90p')^2


forvalues i=1/3{
	local s: word `i' of fullsamp nneighsamp neighsamp
		reg turnout13 pop1011_UNOSAT pop1011_UNOSAT_sq turnout08 turnout02 `maincontrols' if `s'==1,  cluster(district)
			test pop1011_UNOSAT pop1011_UNOSAT_sq
				estadd scalar fstat r(F)
				estadd scalar pval r(p)
			lincom `impact_50p'*pop1011_UNOSAT + `impact_50p2'*pop1011_UNOSAT_sq
				estadd scalar coeff1 r(estimate)
				estadd scalar se1    r(se)
			lincom `impact_75p'*pop1011_UNOSAT + `impact_75p2'*pop1011_UNOSAT_sq
				estadd scalar coeff2 r(estimate)
				estadd scalar se2    r(se)
			lincom `impact_90p'*pop1011_UNOSAT + `impact_90p2'*pop1011_UNOSAT_sq	
				estadd scalar coeff3 r(estimate)
				estadd scalar se3    r(se)
		eststo tB1_`i'
		
		areg turnout13 pop1011_UNOSAT pop1011_UNOSAT_sq turnout08 turnout02 `maincontrols' if `s'==1, a(province) cluster(district)
		estadd local PFE "X"
			test pop1011_UNOSAT pop1011_UNOSAT_sq
				estadd scalar fstat r(F)
				estadd scalar pval r(p)
			lincom `impact_50p'*pop1011_UNOSAT + `impact_50p2'*pop1011_UNOSAT_sq
				estadd scalar coeff1 r(estimate)
				estadd scalar se1    r(se)
			lincom `impact_75p'*pop1011_UNOSAT + `impact_75p2'*pop1011_UNOSAT_sq
				estadd scalar coeff2 r(estimate)
				estadd scalar se2    r(se)
			lincom `impact_90p'*pop1011_UNOSAT + `impact_90p2'*pop1011_UNOSAT_sq	
				estadd scalar coeff3 r(estimate)
				estadd scalar se3    r(se)
		eststo tB1_`i'_PFE
		
		areg turnout13 pop1011_UNOSAT pop1011_UNOSAT_sq turnout08 turnout02 `maincontrols' if `s'==1, a(division) cluster(district)
		estadd local DFE "X"	
			test pop1011_UNOSAT pop1011_UNOSAT_sq
				estadd scalar fstat r(F)
				estadd scalar pval r(p)
			lincom `impact_50p'*pop1011_UNOSAT + `impact_50p2'*pop1011_UNOSAT_sq
				estadd scalar coeff1 r(estimate)
				estadd scalar se1    r(se)
			lincom `impact_75p'*pop1011_UNOSAT + `impact_75p2'*pop1011_UNOSAT_sq
				estadd scalar coeff2 r(estimate)
				estadd scalar se2    r(se)
			lincom `impact_90p'*pop1011_UNOSAT + `impact_90p2'*pop1011_UNOSAT_sq	
				estadd scalar coeff3 r(estimate)
				estadd scalar se3    r(se)
            eststo tB1_`i'_DFE
				}


//Table B.2: Interaction Model with Urbanization

forvalues i=1/3{
	local s: word `i' of fullsamp nneighsamp neighsamp
			eststo tB2_`i': reg turnout13 pop1011_UNOSAT urban pop1011Xurban turnout08 turnout02 `maincontrols' if `s'==1,  cluster(district)
		
			eststo tB2_`i'_PFE: areg turnout13 pop1011_UNOSAT urban pop1011Xurban turnout08 turnout02 `maincontrols' if `s'==1, a(province) cluster(district)
			estadd local PFE "X"
		
			eststo tB2_`i'_DFE: areg turnout13 pop1011_UNOSAT urban pop1011Xurban turnout08 turnout02 `maincontrols' if `s'==1, a(division) cluster(district)
			estadd local DFE "X"	
}

//Table B.3: Replication of Table 1 (Main Result with Different Controls) with Valid Rather than Total Votes in Turnout Numerator

forvalues j=1/3{
	local x: word `j' of " " "d_vt0802" "vturnout08 vturnout02" 
			eststo tB3_`j': reg vturnout13 pop1011_UNOSAT `x' `maincontrols',  cluster(district)
		
			eststo tB3_`j'_PFE: areg vturnout13 pop1011_UNOSAT `x' `maincontrols', a(province) cluster(district)
			estadd local PFE "X"
		
			eststo tB3_`j'_DFE: areg vturnout13 pop1011_UNOSAT `x' `maincontrols', a(division) cluster(district)
			estadd local DFE "X"
}	

//Table B.4: Replication of Table 2 (Main Results for Different Subsets) with Valid Rather than Total Votes in Turnout Numerator

forvalues i=1/3{
	local s: word `i' of fullsamp nneighsamp neighsamp
			eststo tB4_`i': reg vturnout13 pop1011_UNOSAT vturnout08 vturnout02 `maincontrols' if `s'==1,  cluster(district)
		
			eststo tB4_`i'_PFE: areg vturnout13 pop1011_UNOSAT vturnout08 vturnout02 `maincontrols' if `s'==1, a(province) cluster(district)
			estadd local PFE "X"
		
			eststo tB4_`i'_DFE: areg vturnout13 pop1011_UNOSAT vturnout08 vturnout02 `maincontrols' if `s'==1, a(division) cluster(district)
			estadd local DFE "X"	
}

//Table B.5: Results for the Components of Turnout

forvalues i=1/3{
	local s: word `i' of fullsamp nneighsamp neighsamp
		forvalues j=1/3{
		local y: word `j' of vcast13 vtotal13 rvoters13	
			eststo tB5_`i'_`j': reg `y' pop1011_UNOSAT turnout08 turnout02 `maincontrols' if `s'==1, cluster(district)
		
			eststo tB5_`i'_`j'_PFE: areg `y' pop1011_UNOSAT turnout08 turnout02 `maincontrols' if `s'==1, a(province) cluster(district)
			estadd local PFE "X"
		
			eststo tB5_`i'_`j'_DFE: areg `y' pop1011_UNOSAT turnout08 turnout02 `maincontrols' if `s'==1, a(division) cluster(district)
			estadd local DFE "X"
		}
}

//Table B.6: Controlling for Relief

forvalues i=1/3{
	local s: word `i' of fullsamp nneighsamp neighsamp
		eststo tB6_`i': reg turnout13 pop1011_UNOSAT totrelief turnout08 turnout02 `maincontrols' if `s'==1,  cluster(district)
		
		eststo tB6_`i'_PFE: areg turnout13 pop1011_UNOSAT totrelief turnout08 turnout02 `maincontrols' if `s'==1, a(province) cluster(district)
		estadd local PFE "X"
		
		eststo tB6_`i'_DFE: areg turnout13 pop1011_UNOSAT totrelief turnout08 turnout02 `maincontrols' if `s'==1, a(division) cluster(district)
		estadd local DFE "X"	
}

//Table B.7: Controlling for Migration and Limiting Analysis to Places without Migration

forvalues i=1/3{
	local s: word `i' of fullsamp nneighsamp neighsamp
		eststo tB7_`i': reg turnout13 pop1011_UNOSAT migrated_NDMA turnout08 turnout02 `maincontrols' if `s'==1,  cluster(district)
		
		eststo tB7_`i'_PFE: areg turnout13 pop1011_UNOSAT migrated_NDMA turnout08 turnout02 `maincontrols' if `s'==1, a(province) cluster(district)
		estadd local PFE "X"
		
		eststo tB7_`i'_DFE: areg turnout13 pop1011_UNOSAT migrated_NDMA turnout08 turnout02 `maincontrols' if `s'==1, a(division) cluster(district)
		estadd local DFE "X"	

		eststo tB7_0_`i': reg turnout13 pop1011_UNOSAT turnout08 turnout02 `maincontrols' if `s'==1&migrated_NDMA==0|migrated_NDMA==.,  cluster(district)
		
		eststo tB7_0_`i'_PFE: areg turnout13 pop1011_UNOSAT turnout08 turnout02 `maincontrols' if `s'==1&migrated_NDMA==0|migrated_NDMA==., a(province) cluster(district)
		estadd local PFE "X"
		
		eststo tB7_0_`i'_DFE: areg turnout13 pop1011_UNOSAT turnout08 turnout02 `maincontrols' if `s'==1&migrated_NDMA==0|migrated_NDMA==., a(division) cluster(district)
		estadd local DFE "X"	
}

*************************************************************************************
** Appendix C: Supporting Survey Results
*************************************************************************************

use "FKMS_Ind_Data.dta", clear

//Define controls
local placebocontrols           floodrisk centdist_MRiver neigh_Rivers dem_std dem_mean
local indcontrols male headh age read math educ sunni relprac

//Table C.1: Survey Vignette Results

forvalues i=1/2{
	local y: word `i' of effective approve
			eststo tC1_`i'_DFE: areg `y' violent_vignette pop1011_UNOSAT vv_pop1011_UNOSAT `placebocontrols' `indcontrols', a(a7) cluster(psu)
			estadd local DFE "X"
		
			eststo tC1_`i'_TFE: areg `y' violent_vignette flood_exp vv_flood_exp `indcontrols', a(a8) cluster(psu)
			estadd local TFE "X"	
}


//Table C.2: Political Knowledge Results

forvalues i=1/2{
	local y: word `i' of simpleknow knowfullpca
			eststo tC2_`i'_DFE: areg `y' pop1011_UNOSAT `placebocontrols' `indcontrols', a(a7) cluster(psu)
			estadd local DFE "X"
		
			eststo tC2_`i'_TFE: areg `y' flood_exp `indcontrols', a(a8) cluster(psu)
			estadd local TFE "X"	
}

*************************************************************************************/
** Export Main Tables
*************************************************************************************


*Table Locals: 

foreach x in impact_50p impact_75p impact_90p risk_25p risk_50p risk_75p{ 

local `x'=round(``x'', .01) 
}

# delimit ; 

//Table 1
esttab  t1_1
		t1_1_PFE
		t1_1_DFE
		t1_2
		t1_2_PFE
		t1_2_DFE
		t1_3
		t1_3_PFE
		t1_3_DFE
using "TexTables/t1",  
		keep(pop1011_UNOSAT)
		cells(b(fmt(%5.3f) star) se(fmt(%5.3f) par))
		stats(PFE DFE r2 N N_clust, fmt(0 0 3 0 0) label("Province FE" "Division FE" "R-Squared" "Observations" "Clusters"))
		starlevels("" .000000001) 					
		mgroups("\textbf{Controls}" "\textbf{Controls \& Turnout Trend}" "\textbf{Controls \& Turnout Levels}", pattern(1 0 0 1 0 0 1 0 0) 
		span prefix(\multicolumn{@span}{c}{) suffix(}) erepeat(\cmidrule(lr){@span}))		
		nomtitles
		collabels(none)
		varlabels(pop1011_UNOSAT "\% Pop. Exposed")
		prehead("\\ & \multicolumn{9}{c}{\textbf{Turnout 2013} (mean=0.541; sd=0.104)} \\ ")
		noobs
		label 
		booktabs
		nonotes
		fragment  
		replace;

//Table 2
esttab  t2_1
		t2_1_PFE
		t2_1_DFE
		t2_2
		t2_2_PFE
		t2_2_DFE
		t2_3
		t2_3_PFE
		t2_3_DFE
using "TexTables/t2",  
		keep(pop1011_UNOSAT)
		cells(b(fmt(%5.3f) star) se(fmt(%5.3f) par))
		stats(PFE DFE r2 N N_clust, fmt(0 0 3 0 0) label("Province FE" "Division FE" "R-Squared" "Observations" "Clusters"))
		starlevels("" .000000001) 					
		mgroups("\textbf{Full Sample}" "\textbf{Near Maj. Rivers}" "\textbf{Neighboring Maj. River}", pattern(1 0 0 1 0 0 1 0 0) 
		span prefix(\multicolumn{@span}{c}{) suffix(}) erepeat(\cmidrule(lr){@span}))
		nomtitles
		collabels(none)
		varlabels(pop1011_UNOSAT "\% Pop. Exposed")
		noobs
		label 
		booktabs
		nonotes
		fragment  
		replace;


//Table 3
esttab  t3_1_1
		t3_1_1_PFE
		t3_1_1_DFE
		t3_1_2
		t3_1_2_PFE
		t3_1_2_DFE
		t3_1_3
		t3_1_3_PFE
		t3_1_3_DFE
using "TexTables/t3_1",  
		keep(pop1011_UNOSAT)
		cells(b(fmt(%5.3f) star) se(fmt(%5.3f) par))
		stats(PFE DFE r2 N N_clust, fmt(0 0 3 0 0) label("Province FE" "Division FE" "R-Squared" "Observations" "Clusters"))
		starlevels("" .000000001) 					
		mgroups("\textbf{Turnout 2002}" "\textbf{Turnout 2008}" "\textbf{Turnout Difference 08-02}", pattern(1 0 0 1 0 0 1 0 0) 
		span prefix(\multicolumn{@span}{c}{) suffix(}) erepeat(\cmidrule(lr){@span}))
		nomtitles
		collabels(none)
		varlabels(pop1011_UNOSAT "\% Pop. Exposed")
		refcat(pop1011_UNOSAT " \multicolumn{9}{l}{\textbf{Panel A: Full Sample}} \\ \midrule", nolabel)
		noobs
		label 
		booktabs
		nonotes
		fragment  
		replace;

esttab  t3_2_1
		t3_2_1_PFE
		t3_2_1_DFE
		t3_2_2
		t3_2_2_PFE
		t3_2_2_DFE
		t3_2_3
		t3_2_3_PFE
		t3_2_3_DFE
using "TexTables/t3_2",  
		keep(pop1011_UNOSAT)
		cells(b(fmt(%5.3f) star) se(fmt(%5.3f) par))
		stats(PFE DFE r2 N N_clust, fmt(0 0 3 0 0) label("Province FE" "Division FE" "R-Squared" "Observations" "Clusters"))
		starlevels("" .000000001) 					
		nomtitles
		collabels(none)
		varlabels(pop1011_UNOSAT "\% Pop. Exposed")
		prehead("\\ \midrule \multicolumn{9}{l}{\textbf{Panel B: Near Major Rivers}} \\")
		nonum
		noobs
		label 
		booktabs
		nonotes
		fragment  
		replace;

esttab  t3_3_1
		t3_3_1_PFE
		t3_3_1_DFE
		t3_3_2
		t3_3_2_PFE
		t3_3_2_DFE
		t3_3_3
		t3_3_3_PFE
		t3_3_3_DFE
using "TexTables/t3_3",  
		keep(pop1011_UNOSAT)
		cells(b(fmt(%5.3f) star) se(fmt(%5.3f) par))
		stats(PFE DFE r2 N N_clust, fmt(0 0 3 0 0) label("Province FE" "Division FE" "R-Squared" "Observations" "Clusters"))
		starlevels("" .000000001) 					
		nomtitles
		collabels(none)
		varlabels(pop1011_UNOSAT "\% Pop. Exposed")
		prehead("\\ \midrule \multicolumn{9}{l}{\textbf{Panel C: Neighboring Major Rivers}} \\")
		nonum
		noobs
		label 
		booktabs
		nonotes
		fragment  
		replace;

//Table 4
esttab  t4_1_1
		t4_1_1_DFE
		t4_1_2
		t4_1_2_DFE
		t4_1_3
		t4_1_3_DFE
		t4_1_4
		t4_1_4_DFE
using "TexTables/t4_1",  
		keep(pop1011_UNOSAT)
		cells(b(fmt(%5.3f) star) se(fmt(%5.3f) par))
		stats(DFE r2 N N_clust, fmt(0 3 0 0) label("Division FE" "R-Squared" "Observations" "Clusters"))
		starlevels("" .000000001) 					
		mgroups("\textbf{National}" "\textbf{Balochistan \& KPK}" "\textbf{Punjab}" "\textbf{Sindh}", pattern(1 0 1 0 1 0 1 0) 
		span prefix(\multicolumn{@span}{c}{) suffix(}) erepeat(\cmidrule(lr){@span}))
		nomtitles
		collabels(none)
		varlabels(pop1011_UNOSAT "\% Pop. Exposed")
		refcat(pop1011_UNOSAT " \multicolumn{9}{l}{\textbf{Panel A: Provincial Incumbent's Vote Share 2013}} \\ \midrule", nolabel)
		noobs
		label 
		booktabs
		nonotes
		fragment  
		replace;

esttab  t4_2_1
		t4_2_1_DFE
		t4_2_2
		t4_2_2_DFE
		t4_2_3
		t4_2_3_DFE
		t4_2_4
		t4_2_4_DFE
using "TexTables/t4_2",  
		keep(pop1011_UNOSAT)
		cells(b(fmt(%5.3f) star) se(fmt(%5.3f) par))
		stats(DFE r2 N N_clust, fmt(0 3 0 0) label("Division FE" "R-Squared" "Observations" "Clusters"))
		starlevels("" .000000001) 					
		nomtitles
		collabels(none)
		varlabels(pop1011_UNOSAT "\% Pop. Exposed")
		prehead("\\ \midrule \multicolumn{9}{l}{\textbf{Panel B: PPP Vote Share 2013}} \\")
		nonum
		noobs
		label 
		booktabs
		nonotes
		fragment  
		replace;

esttab  t4_3_1
		t4_3_1_DFE
		t4_3_2
		t4_3_2_DFE
		t4_3_3
		t4_3_3_DFE
		t4_3_4
		t4_3_4_DFE
using "TexTables/t4_3",  
		keep(pop1011_UNOSAT)
		cells(b(fmt(%5.3f) star) se(fmt(%5.3f) par))
		stats(DFE r2 N N_clust, fmt(0 3 0 0) label("Division FE" "R-Squared" "Observations" "Clusters"))
		starlevels("" .000000001) 					
		nomtitles
		collabels(none)
		varlabels(pop1011_UNOSAT "\% Pop. Exposed")
		prehead("\\ \midrule \multicolumn{9}{l}{\textbf{Panel C: PML-N Vote Share 2013}} \\")
		nonum
		noobs
		label 
		booktabs
		nonotes
		fragment  
		replace;
		

//Table 5 Panel A (Continuous)
esttab  t5A_1
		t5A_1_PFE
		t5A_1_DFE
		t5A_2
		t5A_2_PFE
		t5A_2_DFE
		t5A_3
		t5A_3_PFE
		t5A_3_DFE
using "TexTables/t5_1",  
		keep(pop1011_UNOSAT floodrisk pop1011Xfloodrisk)
		order(pop1011_UNOSAT floodrisk pop1011Xfloodrisk)
		cells(b(fmt(%5.3f) star) se(fmt(%5.3f) par))
		stats(coeff1 se1 coeff2 se2 coeff3 se3 PFE DFE r2 N N_clust, fmt(3 3 3 3 3 3 0 0 3 0 0) 
		label("\textbf{Marginal Effects:} \\ Flood Risk (25th pctile $= `risk_25p'$)" " " "Flood Risk (Median $= `risk_50p'$)" " " "Flood Risk (75th pctile $= `risk_75p'$)" " " "Province FE" "Division FE" "R-Squared" "Observations" "Clusters")
		layout(@ (@) @ (@) @ (@) @ @ @ @ @))
		starlevels("" .000000001) 					
		mgroups("\textbf{Controls}" "\textbf{Controls \& Turnout Trend}" "\textbf{Controls \& Turnout Levels}", pattern(1 0 0 1 0 0 1 0 0) 
		span prefix(\multicolumn{@span}{c}{) suffix(}) erepeat(\cmidrule(lr){@span}))		
		nomtitles
		collabels(none)
		varlabels(pop1011_UNOSAT "\% Pop. Exposed" floodrisk "Flood Risk" pop1011Xfloodrisk "\% Flooded $\times$ Risk")
		refcat(pop1011_UNOSAT " \multicolumn{9}{l}{\textbf{Panel A: Continuous Interaction}} \\ \midrule", nolabel)
		noobs
		label 
		booktabs
		nonotes
		fragment 
		replace;

//Table 5 Panel B (Dichotomous)
esttab  t5B_1
		t5B_1_PFE
		t5B_1_DFE
		t5B_2
		t5B_2_PFE
		t5B_2_DFE
		t5B_3
		t5B_3_PFE
		t5B_3_DFE
using "TexTables/t5_2",  
		keep(pop1011_UNOSAT frg1 pop1011Xfrg1)
		order(pop1011_UNOSAT frg1 pop1011Xfrg1)
		cells(b(fmt(%5.3f) star) se(fmt(%5.3f) par))
		stats(coeff1 se1 coeff2 se2 coeff3 se3 PFE DFE r2 N N_clust, fmt(3 3 3 3 3 3 0 0 3 0 0) 
		label("\textbf{Effect Differential by Impact:} \\Flood Impact (Median $= `impact_50p'$)" " " "Flood Impact (75th pctile  $= `impact_75p'$)" " " "Flood Impact (90th pctile  $= `impact_90p'$)" " " "Province FE" "Division FE" "R-Squared" "Observations" "Clusters")
		layout(@ (@) @ (@) @ (@) @ @ @ @ @))
		starlevels(* .10 ** .05 *** .01) 					
		nomtitles
		collabels(none)
		varlabels(pop1011_UNOSAT "\% Pop. Exposed" frg1 "Flood Risk $\geq$ 1" pop1011Xfrg1 "\% Flooded $\times$ Risk $\geq$ 1")
		label 
		prehead("\\ \midrule \multicolumn{9}{l}{\textbf{Panel B: Dichtomous Interaction with Flood Risk $\geq$ 1}} \\")
		nonum
		noobs
		booktabs
		nonotes
		fragment  
		replace;

*************************************************************************************/
** Export Appendix B Tables
*************************************************************************************
# delimit;

//Table B.1
esttab  tB1_1
		tB1_1_PFE
		tB1_1_DFE
		tB1_2
		tB1_2_PFE
		tB1_2_DFE
		tB1_3
		tB1_3_PFE
		tB1_3_DFE
using "TexTables/AtB1",  
		keep(pop1011_UNOSAT pop1011_UNOSAT_sq)
		cells(b(fmt(%5.3f) star) se(fmt(%5.3f) par))
		stats(fstat pval coeff1 se1 coeff2 se2 coeff3 se3 PFE DFE r2 N N_clust, fmt(3 3 3 3 3 3 3 3 0 0 3 0 0) 
		label("\textbf{Joint Significance:} \\ F-stat" "p-value" " \hline \textbf{Marginal Effects:} \\ Flood Impact (Median  $= `impact_50p'$)" " " "Flood Impact (75th pctile  $= `impact_75p'$)" " " "Flood Impact (90th pctile  $= `impact_90p'$)" " " "Province FE" "Division FE" "R-Squared" "Observations" "Clusters")
		layout(@ (@) @ (@) @ (@) @ (@) @ @ @ @ @))
		starlevels("" .000000001) 					
		mgroups("\textbf{Full Sample}" "\textbf{Near Maj. Rivers}" "\textbf{Neighboring Maj. River}", pattern(1 0 0 1 0 0 1 0 0) 
		span prefix(\multicolumn{@span}{c}{) suffix(}) erepeat(\cmidrule(lr){@span}))
		nomtitles
		collabels(none)
		varlabels(pop1011_UNOSAT "\% Pop. Exposed" pop1011_UNOSAT_sq "\% Pop. Exposed$^2$")
		noobs
		label 
		booktabs
		nonotes
		fragment  
		replace;

//Table B.2
esttab  tB2_1
		tB2_1_PFE
		tB2_1_DFE
		tB2_2
		tB2_2_PFE
		tB2_2_DFE
		tB2_3
		tB2_3_PFE
		tB2_3_DFE
using "TexTables/AtB2",  
		keep(pop1011_UNOSAT urban pop1011Xurban)
		cells(b(fmt(%5.3f) star) se(fmt(%5.3f) par))
		stats(PFE DFE r2 N N_clust, fmt(0 0 3 0 0) label("Province FE" "Division FE" "R-Squared" "Observations" "Clusters"))
		starlevels("" .000000001) 					
		mgroups("\textbf{Full Sample}" "\textbf{Near Maj. Rivers}" "\textbf{Neighboring Maj. River}", pattern(1 0 0 1 0 0 1 0 0) 
		span prefix(\multicolumn{@span}{c}{) suffix(}) erepeat(\cmidrule(lr){@span}))
		nomtitles
		collabels(none)
		varlabels(pop1011_UNOSAT "\% Pop. Exposed" urban "Urban" pop1011Xurban "\% Flooded $\times$ Urban")
		noobs
		label 
		booktabs
		nonotes
		fragment  
		replace;

//Table B.3
esttab  tB3_1
		tB3_1_PFE
		tB3_1_DFE
		tB3_2
		tB3_2_PFE
		tB3_2_DFE
		tB3_3
		tB3_3_PFE
		tB3_3_DFE
using "TexTables/AtB3",  
		keep(pop1011_UNOSAT)
		cells(b(fmt(%5.3f) star) se(fmt(%5.3f) par))
		stats(PFE DFE r2 N N_clust, fmt(0 0 3 0 0) label("Province FE" "Division FE" "R-Squared" "Observations" "Clusters"))
		starlevels("" .000000001) 					
		mgroups("\textbf{Controls}" "\textbf{Controls \& Turnout Trend}" "\textbf{Controls \& Turnout Levels}", pattern(1 0 0 1 0 0 1 0 0) 
		span prefix(\multicolumn{@span}{c}{) suffix(}) erepeat(\cmidrule(lr){@span}))		
		nomtitles
		collabels(none)
		varlabels(pop1011_UNOSAT "\% Pop. Exposed")
		prehead("\\ & \multicolumn{9}{c}{\textbf{Turnout 2013} (mean=0.525; sd=0.100)} \\ ")
		noobs
		label 
		booktabs
		nonotes
		fragment  
		replace;

//Table B.4
esttab  tB4_1
		tB4_1_PFE
		tB4_1_DFE
		tB4_2
		tB4_2_PFE
		tB4_2_DFE
		tB4_3
		tB4_3_PFE
		tB4_3_DFE
using "TexTables/AtB4",  
		keep(pop1011_UNOSAT)
		cells(b(fmt(%5.3f) star) se(fmt(%5.3f) par))
		stats(PFE DFE r2 N N_clust, fmt(0 0 3 0 0) label("Province FE" "Division FE" "R-Squared" "Observations" "Clusters"))
		starlevels("" .000000001) 					
		mgroups("\textbf{Full Sample}" "\textbf{Near Maj. Rivers}" "\textbf{Neighboring Maj. River}", pattern(1 0 0 1 0 0 1 0 0) 
		span prefix(\multicolumn{@span}{c}{) suffix(}) erepeat(\cmidrule(lr){@span}))
		nomtitles
		collabels(none)
		varlabels(pop1011_UNOSAT "\% Pop. Exposed")
		noobs
		label 
		booktabs
		nonotes
		fragment  
		replace;

//Table B.5
esttab  tB5_1_1
		tB5_1_1_PFE
		tB5_1_1_DFE
		tB5_1_2
		tB5_1_2_PFE
		tB5_1_2_DFE
		tB5_1_3
		tB5_1_3_PFE
		tB5_1_3_DFE
using "TexTables/AtB5_1",  
		keep(pop1011_UNOSAT)
		cells(b(fmt(%5.3f) star) se(fmt(%5.3f) par))
		stats(PFE DFE r2 N N_clust, fmt(0 0 3 0 0) label("Province FE" "Division FE" "R-Squared" "Observations" "Clusters"))
		starlevels("" .000000001) 					
		mgroups("\textbf{Votes Cast 2013}" "\textbf{Valid Votes Cast 2013}" "\textbf{Registered Voters 2013}", pattern(1 0 0 1 0 0 1 0 0) 
		span prefix(\multicolumn{@span}{c}{) suffix(}) erepeat(\cmidrule(lr){@span}))
		refcat(pop1011_UNOSAT " \multicolumn{9}{l}{\textbf{Panel A: Full Sample}} \\ \midrule", nolabel)
		nomtitles
		collabels(none)
		varlabels(pop1011_UNOSAT "\% Pop. Exposed")
		noobs
		label 
		booktabs
		nonotes
		fragment  
		replace;

esttab  tB5_2_1
		tB5_2_1_PFE
		tB5_2_1_DFE
		tB5_2_2
		tB5_2_2_PFE
		tB5_2_2_DFE
		tB5_2_3
		tB5_2_3_PFE
		tB5_2_3_DFE
using "TexTables/AtB5_2",  
		keep(pop1011_UNOSAT)
		cells(b(fmt(%5.3f) star) se(fmt(%5.3f) par))
		stats(PFE DFE r2 N N_clust, fmt(0 0 3 0 0) label("Province FE" "Division FE" "R-Squared" "Observations" "Clusters"))
		starlevels("" .000000001) 					
		prehead("\\ \midrule \multicolumn{9}{l}{\textbf{Panel B: Near Major Rivers}} \\")		
		nomtitles
		collabels(none)
		varlabels(pop1011_UNOSAT "\% Pop. Exposed")
		nonum
		noobs
		label 
		booktabs
		nonotes
		fragment  
		replace;
		
esttab  tB5_3_1
		tB5_3_1_PFE
		tB5_3_1_DFE
		tB5_3_2
		tB5_3_2_PFE
		tB5_3_2_DFE
		tB5_3_3
		tB5_3_3_PFE
		tB5_3_3_DFE
using "TexTables/AtB5_3",  
		keep(pop1011_UNOSAT)
		cells(b(fmt(%5.3f) star) se(fmt(%5.3f) par))
		stats(PFE DFE r2 N N_clust, fmt(0 0 3 0 0) label("Province FE" "Division FE" "R-Squared" "Observations" "Clusters"))
		starlevels("" .000000001) 					
		prehead("\\ \midrule \multicolumn{9}{l}{\textbf{Panel C: Neighboring Major Rivers}} \\")		
		nomtitles
		collabels(none)
		varlabels(pop1011_UNOSAT "\% Pop. Exposed")
		nonum
		noobs
		label 
		booktabs
		nonotes
		fragment  
		replace;
		
//Table B.6
esttab  tB6_1
		tB6_1_PFE
		tB6_1_DFE
		tB6_2
		tB6_2_PFE
		tB6_2_DFE
		tB6_3
		tB6_3_PFE
		tB6_3_DFE
using "TexTables/AtB6",  
		keep(pop1011_UNOSAT totrelief)
		cells(b(fmt(%5.3f) star) se(fmt(%5.3f) par))
		stats(PFE DFE r2 N N_clust, fmt(0 0 3 0 0) label("Province FE" "Division FE" "R-Squared" "Observations" "Clusters"))
		starlevels("" .000000001) 					
		mgroups("\textbf{Full Sample}" "\textbf{Near Maj. Rivers}" "\textbf{Neighboring Maj. River}", pattern(1 0 0 1 0 0 1 0 0) 
		span prefix(\multicolumn{@span}{c}{) suffix(}) erepeat(\cmidrule(lr){@span}))
		nomtitles
		collabels(none)
		varlabels(pop1011_UNOSAT "\% Pop. Exposed" totrelief "Total Relief")
		noobs
		label 
		booktabs
		nonotes
		fragment  
		replace;

//Table B.7
esttab  tB7_1
		tB7_1_PFE
		tB7_1_DFE
		tB7_2
		tB7_2_PFE
		tB7_2_DFE
		tB7_3
		tB7_3_PFE
		tB7_3_DFE
using "TexTables/AtB7_1",  
		keep(pop1011_UNOSAT migrated_NDMA)
		cells(b(fmt(%5.3f) star) se(fmt(%5.3f) par))
		stats(PFE DFE r2 N N_clust, fmt(0 0 3 0 0) label("Province FE" "Division FE" "R-Squared" "Observations" "Clusters"))
		starlevels("" .000000001) 					
		mgroups("\textbf{Full Sample}" "\textbf{Near Maj. Rivers}" "\textbf{Neighboring Maj. River}", pattern(1 0 0 1 0 0 1 0 0) 
		span prefix(\multicolumn{@span}{c}{) suffix(}) erepeat(\cmidrule(lr){@span}))
		refcat(pop1011_UNOSAT " \multicolumn{9}{l}{\textbf{Panel A: Controlling for Migration}} \\ \midrule", nolabel)
		nomtitles
		collabels(none)
		varlabels(pop1011_UNOSAT "\% Pop. Exposed" migrated_NDMA "Migration")
		noobs
		label 
		booktabs
		nonotes
		fragment  
		replace;

esttab  tB7_0_1
		tB7_0_1_PFE
		tB7_0_1_DFE
		tB7_0_2
		tB7_0_2_PFE
		tB7_0_2_DFE
		tB7_0_3
		tB7_0_3_PFE
		tB7_0_3_DFE
using "TexTables/AtB7_2",  
		keep(pop1011_UNOSAT)
		cells(b(fmt(%5.3f) star) se(fmt(%5.3f) par))
		stats(PFE DFE r2 N N_clust, fmt(0 0 3 0 0) label("Province FE" "Division FE" "R-Squared" "Observations" "Clusters"))
		starlevels("" .000000001) 					
		prehead("\\ \midrule \multicolumn{9}{l}{\textbf{Panel B: Subset of Constituencies with No Migration}} \\")				
		nomtitles
		collabels(none)
		varlabels(pop1011_UNOSAT "\% Pop. Exposed")
		nonum
		noobs
		label 
		booktabs
		nonotes
		fragment  
		replace;

*************************************************************************************
** Export Appendix C Tables
*************************************************************************************
# delimit;

//Table C.1
esttab  tC1_1_DFE
		tC1_1_TFE
		tC1_2_DFE
		tC1_2_TFE
using "TexTables/AtC1",  
		keep(violent_vignette pop1011_UNOSAT vv_pop1011_UNOSAT flood_exp vv_flood_exp)
		cells(b(fmt(%5.3f) star) se(fmt(%5.3f) par))
		stats(DFE TFE r2 N N_clust, fmt(0 0 3 0 0) label("Divsion FE" "Tehsil FE" "R-Squared" "Observations" "Clusters"))
		starlevels("" .000000001) 					
		mgroups("\textbf{Effectivness}" "\textbf{Approval}", pattern(1 0 1 0) 
		span prefix(\multicolumn{@span}{c}{) suffix(}) erepeat(\cmidrule(lr){@span}))
		nomtitles
		collabels(none)
		varlabels(violent_vignette "Violent Vignette" pop1011_UNOSAT "\% Pop. Exposed" vv_pop1011_UNOSAT "Violence $\times$ \% Flooded" flood_exp "Flood Exposure" vv_flood_exp "Violence $\times$ Exposure")
		noobs
		label 
		booktabs
		nonotes
		fragment  
		replace;

//Table C.2
esttab  tC2_1_DFE
		tC2_1_TFE
		tC2_2_DFE
		tC2_2_TFE
using "TexTables/AtC2",  
		keep(pop1011_UNOSAT flood_exp)
		cells(b(fmt(%5.3f) star) se(fmt(%5.3f) par))
		stats(DFE TFE r2 N N_clust, fmt(0 0 3 0 0) label("Divsion FE" "Tehsil FE" "R-Squared" "Observations" "Clusters"))
		starlevels("" .000000001) 					
		mgroups("\textbf{Additive Index}" "\textbf{PCA Index}", pattern(1 0 1 0) 
		span prefix(\multicolumn{@span}{c}{) suffix(}) erepeat(\cmidrule(lr){@span}))
		nomtitles
		collabels(none)
		varlabels(pop1011_UNOSAT "\% Pop. Exposed" flood_exp "Flood Exposure")
		noobs
		label 
		booktabs
		nonotes
		fragment  
		replace;

capture log close
