##############################################
## Replication Code for GG-Plot Figures
##
## Created: June 27, 2016
## Christine Fair, Patrick M Kuhn, Neil Malhotra and Jake Shapiro
## Updated: 
##
##############################################

#Load Packages
library("ggplot2")
library("scales")
library("gridExtra")
library("reshape2")

#Set Working Directory
setwd("~/Desktop/QJPS/15075/Iteration 1/Replication Material") #Set working directory

#####################
##Figure 2: Standardized Impact of Pakistani Floods 1975-2012
#####################

#Load Data
dat<-read.table("PAKFloodsGraph.csv", sep=",", header=TRUE)
attach(dat)

#Replace NAs with zero
dat[is.na(dat)] <- 0
attach(dat)

###########
#Data for Graph Part 1 (zkilled and zaffected)
datA1<-cbind(zaffected, zkilled)
datA2<-melt(datA1, id.vars=c("zkilled", "zaffected"))
vA<-as.integer(c(rep(year,2)))
datA<-as.data.frame(cbind(datA2,vA))

#Plot Graph Part 1
ga<-ggplot(datA, aes(x=vA, y=value, fill=Var2)) + #define data and variables used for the plot 
  geom_bar(stat="identity", position=position_dodge()) + #define plot design
  labs(x="", y="z-score killed/affected\n") + #add axis labels
  scale_fill_manual(breaks=c("zkilled","zaffected"), labels=c("Killed","Affected"), values=c("#CCCCCC","#333333"), name="") +
  theme(legend.key.height=unit(1,"line")) + #Spacing between legend parts
  theme(axis.text.x=element_text(angle=90, hjust=1, colour="#000000", size=20)) + #turns x axis scales 90 degree and adjusts them to the axis
  theme(axis.text.y=element_text(colour="#000000", size=20)) + #makes scale on y axis black
  theme(axis.title.y=element_text(hjust=0.55, angle=90, size=22)) + #placing the y axis label and turing it 90 degrees
  theme(axis.title.x=element_text(size=22)) + #define letter size x axis
  scale_x_continuous(breaks=seq(1975, 2010, 5)) +
  theme(legend.text=element_text(size=18)) + #define letter size legend
  ggtitle(expression(atop("Pakistan Floods 1975-2012", atop("Source: International Disaster Database (EM-DAT)"), ""))) + #adds the main title
  theme(plot.title = element_text(size = 26, face="bold")) + #size letters main title
  theme(legend.key.height=unit(2, "line")) + #increase size of legend boxes    
  theme(panel.background=element_rect(fill="white"))

#Data for Graph Part 2 (zdeath and zdisplaced)
datB1<-cbind(zdeath, zdisplaced)
datB2<-melt(datB1, id.vars=c("zdeath", "zdisplaced"))
vA<-as.integer(c(rep(year,2)))
datB<-as.data.frame(cbind(datB2,vA))
datB$Var2<-factor(datB$Var2, levels=c("zdisplaced", "zdeath"))

#Plot Graph Part 2
gb<-ggplot(datB, aes(x=vA, y=value, fill=Var2)) + #define data and variables used for the plot 
  geom_bar(stat="identity", position=position_dodge()) + #define plot design
  labs(x="Year", y="z-score deaths/displaced\n") + #add axis labels
  scale_fill_manual(breaks=c("zdeath","zdisplaced"), labels=c("Death","Displaced"), values=c("#CCCCCC", "#333333"), name="") +
  theme(legend.key.height=unit(1,"line")) + #Spacing between legend parts
  theme(axis.text.x=element_text(angle=90, hjust=1, colour="#000000", size=20)) + #turns x axis scales 90 degree and adjusts them to the axis
  theme(axis.text.y=element_text(colour="#000000", size=20)) + #makes scale on y axis black
  theme(axis.title.y=element_text(hjust=0.55, angle=90, size=22)) + #placing the y axis label and turing it 90 degrees
  theme(axis.title.x=element_text(size=22)) + #define letter size x axis
  theme(legend.text=element_text(size=18)) + #define letter size legend
  scale_x_continuous(breaks=seq(1975, 2010, 5)) +
  ggtitle(expression(atop("", atop("Source: Dartmouth Flood Observatory (DFO)"), ""))) + #adds the main title
  theme(plot.title = element_text(size = 26, face="bold")) + #size letters main title
  theme(legend.key.height=unit(2, "line")) + #increase size of legend boxes
  theme(panel.background=element_rect(fill="white"))

#Combine Part 1 and Part 2
fig2<-arrangeGrob(ga,gb, ncol=1) #combines the previous two graphs, which are the usage of each method for each cluster separately.

#Save combined plot
ggsave(fig2, file="Figures/PAKFloodsII.pdf", width=18, height=12, dpi = 2400)

detach(dat)

#####################
##Figure 3: Scatter Plots of UNEP Flood Risk versus Effective Flood Exposure 2010/11
#####################

exp<-read.table("ScatterplotsData.csv", sep=",", header=TRUE)
attach(exp)

#New variable to label area and population
AP2<-as.matrix(c(rep("Area",1167),rep("Population",1167)))
exp2<-as.data.frame(cbind(exp,AP2))

#Set order for facets
exp2$unit_o <- factor(exp2$unit, levels=c("Tehsils", "NA Constituencies", "PA Constituencies"))

FigExp<-ggplot(exp2, aes(x= floodrisk, y= expo)) + #define dataset, x and y
  geom_point(shape=16, size=3) + #define plot and point design
  facet_grid(AP2 ~ unit_o) + #facet area and population and labeling the two graphs
  ylab("Proportion Exposed") + #title y axis
  xlab("UNEP Flood Risk Index (1-5)") + #title x axis
  theme(axis.text.x=element_text(colour="#000000", size=18)) + #x label black and size
  theme(axis.title.x=element_text(size=20, vjust=0.2)) +  #placing the x axis label  and adjusting letter size
  theme(axis.text.y=element_text(colour="#000000", size=18)) + #makes scale on y axis black and size
  theme(axis.title.y=element_text(size=20, angle=90, vjust=0.2)) +  #placing the y axis label  and adjusting letter size
  theme(strip.text.x = element_text(size = 18)) + #defines size and orientation of facet titles
  theme(strip.text.y = element_text(size = 18)) #defines size and orientation of facet titles

ggsave(FigExp, file="Figures/ExposureFloodrisk6Scatterplots.pdf", width=18, height=12, dpi = 2400)

detach(exp)

